"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeFirewallXAllow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTS_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    protocol: builtins.str
    def __init__(
        self,
        *,
        ports: collections.abc.Iterable[builtins.str] | None = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ports", b"ports", "protocol", b"protocol"]) -> None: ...

global___ComputeFirewallXAllow = ComputeFirewallXAllow

@typing_extensions.final
class ComputeFirewallXDeny(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTS_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    protocol: builtins.str
    def __init__(
        self,
        *,
        ports: collections.abc.Iterable[builtins.str] | None = ...,
        protocol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ports", b"ports", "protocol", b"protocol"]) -> None: ...

global___ComputeFirewallXDeny = ComputeFirewallXDeny

@typing_extensions.final
class ComputeFirewallXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    metadata: builtins.str
    def __init__(
        self,
        *,
        metadata: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata"]) -> None: ...

global___ComputeFirewallXLogConfig = ComputeFirewallXLogConfig

@typing_extensions.final
class ComputeFirewallXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeFirewallXTimeouts = ComputeFirewallXTimeouts

@typing_extensions.final
class ComputeFirewall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESTINATION_RANGES_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    ENABLE_LOGGING_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SOURCE_RANGES_FIELD_NUMBER: builtins.int
    SOURCE_SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    SOURCE_TAGS_FIELD_NUMBER: builtins.int
    TARGET_SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    TARGET_TAGS_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    DENY_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    @property
    def destination_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    direction: builtins.str
    disabled: builtins.bool
    enable_logging: builtins.bool
    id: builtins.str
    name: builtins.str
    network: builtins.str
    priority: builtins.float
    project: builtins.str
    self_link: builtins.str
    @property
    def source_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_service_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def target_service_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def target_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeFirewallXAllow]: ...
    @property
    def deny(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeFirewallXDeny]: ...
    @property
    def log_config(self) -> global___ComputeFirewallXLogConfig: ...
    @property
    def timeouts(self) -> global___ComputeFirewallXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        destination_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        direction: builtins.str = ...,
        disabled: builtins.bool = ...,
        enable_logging: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        priority: builtins.float = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        source_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        source_service_accounts: collections.abc.Iterable[builtins.str] | None = ...,
        source_tags: collections.abc.Iterable[builtins.str] | None = ...,
        target_service_accounts: collections.abc.Iterable[builtins.str] | None = ...,
        target_tags: collections.abc.Iterable[builtins.str] | None = ...,
        allow: collections.abc.Iterable[global___ComputeFirewallXAllow] | None = ...,
        deny: collections.abc.Iterable[global___ComputeFirewallXDeny] | None = ...,
        log_config: global___ComputeFirewallXLogConfig | None = ...,
        timeouts: global___ComputeFirewallXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_config", b"log_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow", b"allow", "creation_timestamp", b"creation_timestamp", "deny", b"deny", "description", b"description", "destination_ranges", b"destination_ranges", "direction", b"direction", "disabled", b"disabled", "enable_logging", b"enable_logging", "id", b"id", "log_config", b"log_config", "name", b"name", "network", b"network", "priority", b"priority", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "source_ranges", b"source_ranges", "source_service_accounts", b"source_service_accounts", "source_tags", b"source_tags", "target_service_accounts", b"target_service_accounts", "target_tags", b"target_tags", "timeouts", b"timeouts"]) -> None: ...

global___ComputeFirewall = ComputeFirewall

@typing_extensions.final
class ComputeFirewallPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeFirewallPolicyXTimeouts = ComputeFirewallPolicyXTimeouts

@typing_extensions.final
class ComputeFirewallPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    RULE_TUPLE_COUNT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SELF_LINK_WITH_ID_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    fingerprint: builtins.str
    firewall_policy_id: builtins.str
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    rule_tuple_count: builtins.float
    self_link: builtins.str
    self_link_with_id: builtins.str
    short_name: builtins.str
    @property
    def timeouts(self) -> global___ComputeFirewallPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        firewall_policy_id: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        rule_tuple_count: builtins.float = ...,
        self_link: builtins.str = ...,
        self_link_with_id: builtins.str = ...,
        short_name: builtins.str = ...,
        timeouts: global___ComputeFirewallPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "fingerprint", b"fingerprint", "firewall_policy_id", b"firewall_policy_id", "id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "rule_tuple_count", b"rule_tuple_count", "self_link", b"self_link", "self_link_with_id", b"self_link_with_id", "short_name", b"short_name", "timeouts", b"timeouts"]) -> None: ...

global___ComputeFirewallPolicy = ComputeFirewallPolicy

@typing_extensions.final
class ComputeFirewallPolicyAssociationXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeFirewallPolicyAssociationXTimeouts = ComputeFirewallPolicyAssociationXTimeouts

@typing_extensions.final
class ComputeFirewallPolicyAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTACHMENT_TARGET_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attachment_target: builtins.str
    firewall_policy: builtins.str
    id: builtins.str
    name: builtins.str
    short_name: builtins.str
    @property
    def timeouts(self) -> global___ComputeFirewallPolicyAssociationXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attachment_target: builtins.str = ...,
        firewall_policy: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        short_name: builtins.str = ...,
        timeouts: global___ComputeFirewallPolicyAssociationXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_target", b"attachment_target", "firewall_policy", b"firewall_policy", "id", b"id", "name", b"name", "resource_info", b"resource_info", "short_name", b"short_name", "timeouts", b"timeouts"]) -> None: ...

global___ComputeFirewallPolicyAssociation = ComputeFirewallPolicyAssociation

@typing_extensions.final
class ComputeFirewallPolicyRuleXMatchXLayer4Configs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    ip_protocol: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        ip_protocol: builtins.str = ...,
        ports: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_protocol", b"ip_protocol", "ports", b"ports"]) -> None: ...

global___ComputeFirewallPolicyRuleXMatchXLayer4Configs = ComputeFirewallPolicyRuleXMatchXLayer4Configs

@typing_extensions.final
class ComputeFirewallPolicyRuleXMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEST_IP_RANGES_FIELD_NUMBER: builtins.int
    SRC_IP_RANGES_FIELD_NUMBER: builtins.int
    LAYER4_CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def dest_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def src_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def layer4_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeFirewallPolicyRuleXMatchXLayer4Configs]: ...
    def __init__(
        self,
        *,
        dest_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        src_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        layer4_configs: collections.abc.Iterable[global___ComputeFirewallPolicyRuleXMatchXLayer4Configs] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dest_ip_ranges", b"dest_ip_ranges", "layer4_configs", b"layer4_configs", "src_ip_ranges", b"src_ip_ranges"]) -> None: ...

global___ComputeFirewallPolicyRuleXMatch = ComputeFirewallPolicyRuleXMatch

@typing_extensions.final
class ComputeFirewallPolicyRuleXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeFirewallPolicyRuleXTimeouts = ComputeFirewallPolicyRuleXTimeouts

@typing_extensions.final
class ComputeFirewallPolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    ENABLE_LOGGING_FIELD_NUMBER: builtins.int
    FIREWALL_POLICY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_TUPLE_COUNT_FIELD_NUMBER: builtins.int
    TARGET_RESOURCES_FIELD_NUMBER: builtins.int
    TARGET_SERVICE_ACCOUNTS_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    direction: builtins.str
    disabled: builtins.bool
    enable_logging: builtins.bool
    firewall_policy: builtins.str
    id: builtins.str
    kind: builtins.str
    priority: builtins.float
    rule_tuple_count: builtins.float
    @property
    def target_resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def target_service_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def match(self) -> global___ComputeFirewallPolicyRuleXMatch: ...
    @property
    def timeouts(self) -> global___ComputeFirewallPolicyRuleXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        direction: builtins.str = ...,
        disabled: builtins.bool = ...,
        enable_logging: builtins.bool = ...,
        firewall_policy: builtins.str = ...,
        id: builtins.str = ...,
        kind: builtins.str = ...,
        priority: builtins.float = ...,
        rule_tuple_count: builtins.float = ...,
        target_resources: collections.abc.Iterable[builtins.str] | None = ...,
        target_service_accounts: collections.abc.Iterable[builtins.str] | None = ...,
        match: global___ComputeFirewallPolicyRuleXMatch | None = ...,
        timeouts: global___ComputeFirewallPolicyRuleXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match", b"match", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "direction", b"direction", "disabled", b"disabled", "enable_logging", b"enable_logging", "firewall_policy", b"firewall_policy", "id", b"id", "kind", b"kind", "match", b"match", "priority", b"priority", "resource_info", b"resource_info", "rule_tuple_count", b"rule_tuple_count", "target_resources", b"target_resources", "target_service_accounts", b"target_service_accounts", "timeouts", b"timeouts"]) -> None: ...

global___ComputeFirewallPolicyRule = ComputeFirewallPolicyRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.coordination.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6kubernetes/kubernetes_io.k8s.api.coordination.v1.proto\x12#oak9.tython.k8s.api.coordination.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xee\x01\n\x05Lease\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x04spec\x18\x04 \x01(\x0b\x32..oak9.tython.k8s.api.coordination.v1.LeaseSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\tLeaseList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.oak9.tython.k8s.api.coordination.v1.Lease\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb6\x02\n\tLeaseSpec\x12N\n\x0c\x61\x63quire_time\x18\x01 \x01(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.MicroTime\x12\x17\n\x0fholder_identity\x18\x02 \x01(\t\x12\x1e\n\x16lease_duration_seconds\x18\x03 \x01(\x05\x12\x19\n\x11lease_transitions\x18\x04 \x01(\x05\x12L\n\nrenew_time\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.MicroTime\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.coordination.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEASE._serialized_start=183
  _LEASE._serialized_end=421
  _LEASELIST._serialized_start=424
  _LEASELIST._serialized_end=661
  _LEASESPEC._serialized_start=664
  _LEASESPEC._serialized_end=974
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_vpcendpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_ec2_vpcendpoint.proto\x12\x1foak9.tython.aws.ec2_vpcendpoint\x1a\x13shared/shared.proto\"\xff\x02\n\x0bVPCEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x0fpolicy_document\x18\x02 \x03(\x0b\x32@.oak9.tython.aws.ec2_vpcendpoint.VPCEndpoint.PolicyDocumentEntry\x12\x1b\n\x13private_dns_enabled\x18\x03 \x01(\x08\x12\x17\n\x0froute_table_ids\x18\x04 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\t\x12\x14\n\x0cservice_name\x18\x06 \x01(\t\x12\x12\n\nsubnet_ids\x18\x07 \x03(\t\x12\x19\n\x11vpc_endpoint_type\x18\x08 \x01(\t\x12\x0e\n\x06vpc_id\x18\t \x01(\t\x1a\x35\n\x13PolicyDocumentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x02\n\x0f\x45\x43\x32_VPCEndpoint\x12\x42\n\x0cvpc_endpoint\x18\x01 \x01(\x0b\x32,.oak9.tython.aws.ec2_vpcendpoint.VPCEndpoint\x12Q\n\x14vpc_endpoint_service\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.ec2_vpcendpoint.VPCEndpointService\x12h\n vpc_endpoint_service_permissions\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.ec2_vpcendpoint.VPCEndpointServicePermissions\"\xb4\x01\n\x12VPCEndpointService\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1anetwork_load_balancer_arns\x18\x02 \x03(\t\x12\x1b\n\x13\x61\x63\x63\x65ptance_required\x18\x03 \x01(\x08\x12$\n\x1c\x61ppliance_load_balancer_arns\x18\x04 \x03(\t\"\x88\x01\n\x1dVPCEndpointServicePermissions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x61llowed_principals\x18\x02 \x03(\t\x12\x12\n\nservice_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_vpcendpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VPCENDPOINT_POLICYDOCUMENTENTRY._options = None
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_options = b'8\001'
  _VPCENDPOINT._serialized_start=88
  _VPCENDPOINT._serialized_end=471
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_start=418
  _VPCENDPOINT_POLICYDOCUMENTENTRY._serialized_end=471
  _EC2_VPCENDPOINT._serialized_start=474
  _EC2_VPCENDPOINT._serialized_end=748
  _VPCENDPOINTSERVICE._serialized_start=751
  _VPCENDPOINTSERVICE._serialized_end=931
  _VPCENDPOINTSERVICEPERMISSIONS._serialized_start=934
  _VPCENDPOINTSERVICEPERMISSIONS._serialized_end=1070
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_apikeys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_apikeys.proto\x12\x17oak9.tython.gcp.apikeys\x1a\x13shared/shared.proto\"t\nBApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x18\n\x10sha1_fingerprint\x18\x02 \x01(\t\"\xab\x01\n.ApikeysKeyXRestrictionsXAndroidKeyRestrictions\x12y\n\x14\x61llowed_applications\x18\x01 \x03(\x0b\x32[.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications\"F\n\"ApikeysKeyXRestrictionsXApiTargets\x12\x0f\n\x07methods\x18\x01 \x03(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\"K\n.ApikeysKeyXRestrictionsXBrowserKeyRestrictions\x12\x19\n\x11\x61llowed_referrers\x18\x01 \x03(\t\"H\n*ApikeysKeyXRestrictionsXIosKeyRestrictions\x12\x1a\n\x12\x61llowed_bundle_ids\x18\x01 \x03(\t\"D\n-ApikeysKeyXRestrictionsXServerKeyRestrictions\x12\x13\n\x0b\x61llowed_ips\x18\x01 \x03(\t\"\x8d\x04\n\x17\x41pikeysKeyXRestrictions\x12i\n\x18\x61ndroid_key_restrictions\x18\x01 \x01(\x0b\x32G.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXAndroidKeyRestrictions\x12P\n\x0b\x61pi_targets\x18\x02 \x03(\x0b\x32;.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXApiTargets\x12i\n\x18\x62rowser_key_restrictions\x18\x03 \x01(\x0b\x32G.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXBrowserKeyRestrictions\x12\x61\n\x14ios_key_restrictions\x18\x04 \x01(\x0b\x32\x43.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXIosKeyRestrictions\x12g\n\x17server_key_restrictions\x18\x05 \x01(\x0b\x32\x46.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictionsXServerKeyRestrictions\"E\n\x13\x41pikeysKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaf\x02\n\nApikeysKey\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nkey_string\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x46\n\x0crestrictions\x18\x07 \x01(\x0b\x32\x30.oak9.tython.gcp.apikeys.ApikeysKeyXRestrictions\x12>\n\x08timeouts\x18\x08 \x01(\x0b\x32,.oak9.tython.gcp.apikeys.ApikeysKeyXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_apikeys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIKEYSKEYXRESTRICTIONSXANDROIDKEYRESTRICTIONSXALLOWEDAPPLICATIONS._serialized_start=71
  _APIKEYSKEYXRESTRICTIONSXANDROIDKEYRESTRICTIONSXALLOWEDAPPLICATIONS._serialized_end=187
  _APIKEYSKEYXRESTRICTIONSXANDROIDKEYRESTRICTIONS._serialized_start=190
  _APIKEYSKEYXRESTRICTIONSXANDROIDKEYRESTRICTIONS._serialized_end=361
  _APIKEYSKEYXRESTRICTIONSXAPITARGETS._serialized_start=363
  _APIKEYSKEYXRESTRICTIONSXAPITARGETS._serialized_end=433
  _APIKEYSKEYXRESTRICTIONSXBROWSERKEYRESTRICTIONS._serialized_start=435
  _APIKEYSKEYXRESTRICTIONSXBROWSERKEYRESTRICTIONS._serialized_end=510
  _APIKEYSKEYXRESTRICTIONSXIOSKEYRESTRICTIONS._serialized_start=512
  _APIKEYSKEYXRESTRICTIONSXIOSKEYRESTRICTIONS._serialized_end=584
  _APIKEYSKEYXRESTRICTIONSXSERVERKEYRESTRICTIONS._serialized_start=586
  _APIKEYSKEYXRESTRICTIONSXSERVERKEYRESTRICTIONS._serialized_end=654
  _APIKEYSKEYXRESTRICTIONS._serialized_start=657
  _APIKEYSKEYXRESTRICTIONS._serialized_end=1182
  _APIKEYSKEYXTIMEOUTS._serialized_start=1184
  _APIKEYSKEYXTIMEOUTS._serialized_end=1253
  _APIKEYSKEY._serialized_start=1256
  _APIKEYSKEY._serialized_end=1559
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_ec2_instance.proto\x12\x1coak9.tython.aws.ec2_instance\x1a\x13shared/shared.proto\"\xd9\x01\n\x0bInstanceEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x11\n\tencrypted\x18\x03 \x01(\x08\x12\x0c\n\x04iops\x18\x04 \x01(\x05\x12\x12\n\nkms_key_id\x18\x05 \x01(\t\x12\x13\n\x0bsnapshot_id\x18\x06 \x01(\t\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"K\n\x10InstanceNoDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x1aInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x36\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32).oak9.tython.aws.ec2_instance.InstanceEbs\x12\x41\n\tno_device\x18\x04 \x01(\x0b\x32..oak9.tython.aws.ec2_instance.InstanceNoDevice\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"{\n\x12InstanceCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncore_count\x18\x02 \x01(\x05\x12\x18\n\x10threads_per_core\x18\x03 \x01(\x05\"k\n\x1bInstanceCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"Z\n\x1fInstanceElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n#InstanceElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"i\n\x1aInstanceHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"l\n\x1bInstanceInstanceIpv6Address\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xa9\x01\n#InstanceLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"z\n\x1cInstanceLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\x8d\x01\n%InstancePrivateIpAddressSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07primary\x18\x02 \x01(\x08\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\"\xa0\x04\n\x18InstanceNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x61ssociate_public_ip_address\x18\x02 \x01(\x08\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65vice_index\x18\x05 \x01(\t\x12\x11\n\tgroup_set\x18\x06 \x03(\t\x12\x1a\n\x12ipv6_address_count\x18\x07 \x01(\x05\x12Q\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceInstanceIpv6Address\x12\x1c\n\x14network_interface_id\x18\t \x01(\t\x12\x1a\n\x12private_ip_address\x18\n \x01(\t\x12\x61\n\x14private_ip_addresses\x18\x0b \x03(\x0b\x32\x43.oak9.tython.aws.ec2_instance.InstancePrivateIpAddressSpecification\x12*\n\"secondary_private_ip_address_count\x18\x0c \x01(\x05\x12\x11\n\tsubnet_id\x18\r \x01(\t\"s\n\x1cInstanceAssociationParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x03(\t\"\xc4\x01\n\x16InstanceSsmAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x16\x61ssociation_parameters\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.ec2_instance.InstanceAssociationParameter\x12\x15\n\rdocument_name\x18\x03 \x01(\t\"l\n\x0eInstanceVolume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x11\n\tvolume_id\x18\x03 \x01(\t\"\xc7\x0e\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x03 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\t\x12W\n\x15\x62lock_device_mappings\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.ec2_instance.InstanceBlockDeviceMapping\x12\x45\n\x0b\x63pu_options\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.ec2_instance.InstanceCpuOptions\x12W\n\x14\x63redit_specification\x18\x07 \x01(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceCreditSpecification\x12\x1f\n\x17\x64isable_api_termination\x18\x08 \x01(\x08\x12\x15\n\rebs_optimized\x18\t \x01(\x08\x12\x61\n\x1a\x65lastic_gpu_specifications\x18\n \x03(\x0b\x32=.oak9.tython.aws.ec2_instance.InstanceElasticGpuSpecification\x12i\n\x1e\x65lastic_inference_accelerators\x18\x0b \x03(\x0b\x32\x41.oak9.tython.aws.ec2_instance.InstanceElasticInferenceAccelerator\x12U\n\x13hibernation_options\x18\x0c \x01(\x0b\x32\x38.oak9.tython.aws.ec2_instance.InstanceHibernationOptions\x12\x0f\n\x07host_id\x18\r \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\x0e \x01(\t\x12\x1c\n\x14iam_instance_profile\x18\x0f \x01(\t\x12\x10\n\x08image_id\x18\x10 \x01(\t\x12,\n$instance_initiated_shutdown_behavior\x18\x11 \x01(\t\x12\x15\n\rinstance_type\x18\x12 \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x13 \x01(\x05\x12Q\n\x0eipv6_addresses\x18\x14 \x03(\x0b\x32\x39.oak9.tython.aws.ec2_instance.InstanceInstanceIpv6Address\x12\x11\n\tkernel_id\x18\x15 \x01(\t\x12\x10\n\x08key_name\x18\x16 \x01(\t\x12Z\n\x0flaunch_template\x18\x17 \x01(\x0b\x32\x41.oak9.tython.aws.ec2_instance.InstanceLaunchTemplateSpecification\x12Z\n\x16license_specifications\x18\x18 \x03(\x0b\x32:.oak9.tython.aws.ec2_instance.InstanceLicenseSpecification\x12\x12\n\nmonitoring\x18\x19 \x01(\x08\x12R\n\x12network_interfaces\x18\x1a \x03(\x0b\x32\x36.oak9.tython.aws.ec2_instance.InstanceNetworkInterface\x12\x1c\n\x14placement_group_name\x18\x1b \x01(\t\x12\x1a\n\x12private_ip_address\x18\x1c \x01(\t\x12\x12\n\nramdisk_id\x18\x1d \x01(\t\x12\x1a\n\x12security_group_ids\x18\x1e \x03(\t\x12\x17\n\x0fsecurity_groups\x18\x1f \x03(\t\x12\x19\n\x11source_dest_check\x18  \x01(\x08\x12N\n\x10ssm_associations\x18! \x03(\x0b\x32\x34.oak9.tython.aws.ec2_instance.InstanceSsmAssociation\x12\x11\n\tsubnet_id\x18\" \x01(\t\x12>\n\x04tags\x18# \x03(\x0b\x32\x30.oak9.tython.aws.ec2_instance.Instance.TagsEntry\x12\x0f\n\x07tenancy\x18$ \x01(\t\x12\x11\n\tuser_data\x18% \x01(\t\x12=\n\x07volumes\x18& \x03(\x0b\x32,.oak9.tython.aws.ec2_instance.InstanceVolume\x12:\n\tplacement\x18\' \x01(\x0b\x32\'.oak9.tython.aws.ec2_instance.Placement\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x0c\x45\x43\x32_Instance\x12\x38\n\x08instance\x18\x01 \x01(\x0b\x32&.oak9.tython.aws.ec2_instance.Instance\x12\x45\n\x0flaunch_template\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.ec2_instance.LaunchTemplate\"\xf3\x01\n\x1eLaunchTemplateTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12T\n\x04tags\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.ec2_instance.LaunchTemplateTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x11LaunchTemplateEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsnapshot_id\x18\x02 \x01(\t\x12\x13\n\x0bvolume_type\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x11\n\tencrypted\x18\x05 \x01(\x08\x12\x0c\n\x04iops\x18\x06 \x01(\x05\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x08 \x01(\x08\"\xd7\x01\n LaunchTemplateBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x03\x65\x62s\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.ec2_instance.LaunchTemplateEbs\x12\x11\n\tno_device\x18\x03 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x05 \x01(\t\"v\n LaunchTemplateIamInstanceProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"`\n%LaunchTemplateElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n7LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x87\x02\n\x17LaunchTemplatePlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0f\n\x07tenancy\x18\x03 \x01(\t\x12\x15\n\rspread_domain\x18\x04 \x01(\t\x12\x18\n\x10partition_number\x18\x05 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x07 \x01(\t\x12\x0f\n\x07host_id\x18\x08 \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\t \x01(\t\"\x82\x01\n\x1aLaunchTemplatePrivateIpAdd\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12private_ip_address\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"f\n\x15LaunchTemplateIpv6Add\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xaa\x04\n\x1eLaunchTemplateNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\x12V\n\x14private_ip_addresses\x18\x04 \x03(\x0b\x32\x38.oak9.tython.aws.ec2_instance.LaunchTemplatePrivateIpAdd\x12*\n\"secondary_private_ip_address_count\x18\x05 \x01(\x05\x12\x14\n\x0c\x64\x65vice_index\x18\x06 \x01(\x05\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12K\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x33.oak9.tython.aws.ec2_instance.LaunchTemplateIpv6Add\x12#\n\x1b\x61ssociate_public_ip_address\x18\t \x01(\x08\x12\x1c\n\x14network_interface_id\x18\n \x01(\t\x12\x16\n\x0einterface_type\x18\x0b \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x0c \x01(\x05\x12\x0e\n\x06groups\x18\r \x03(\t\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x0e \x01(\x08\"d\n\x18LaunchTemplateMonitoring\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"o\n LaunchTemplateHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"\xa9\x01\n\x1dLaunchTemplateMetadataOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bhttp_put_response_hop_limit\x18\x02 \x01(\x05\x12\x13\n\x0bhttp_tokens\x18\x03 \x01(\t\x12\x15\n\rhttp_endpoint\x18\x04 \x01(\t\"\x80\x01\n\"LaunchTemplateLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\x81\x01\n\x18LaunchTemplateCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x05\x12\x12\n\ncore_count\x18\x03 \x01(\x05\"\xe0\x01\n\x19LaunchTemplateSpotOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12spot_instance_type\x18\x02 \x01(\t\x12&\n\x1einstance_interruption_behavior\x18\x03 \x01(\t\x12\x11\n\tmax_price\x18\x04 \x01(\t\x12\x1e\n\x16\x62lock_duration_minutes\x18\x05 \x01(\x05\x12\x13\n\x0bvalid_until\x18\x06 \x01(\t\"\xc2\x01\n#LaunchTemplateInstanceMarketOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0cspot_options\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_instance.LaunchTemplateSpotOptions\x12\x13\n\x0bmarket_type\x18\x03 \x01(\t\"\x83\x01\n\'LaunchTemplateCapacityReservationTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61pacity_reservation_id\x18\x02 \x01(\t\"\xfe\x01\n.LaunchTemplateCapacityReservationSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x63\x61pacity_reservation_preference\x18\x02 \x01(\t\x12j\n\x1b\x63\x61pacity_reservation_target\x18\x03 \x01(\x0b\x32\x45.oak9.tython.aws.ec2_instance.LaunchTemplateCapacityReservationTarget\"q\n!LaunchTemplateCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"\xfb\r\n LaunchTemplateLaunchTemplateData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_groups\x18\x02 \x03(\t\x12X\n\x12tag_specifications\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.ec2_instance.LaunchTemplateTagSpecification\x12\x11\n\tuser_data\x18\x04 \x01(\t\x12]\n\x15\x62lock_device_mappings\x18\x05 \x03(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateBlockDeviceMapping\x12\\\n\x14iam_instance_profile\x18\x06 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateIamInstanceProfile\x12\x11\n\tkernel_id\x18\x07 \x01(\t\x12\x15\n\rebs_optimized\x18\x08 \x01(\x08\x12g\n\x1a\x65lastic_gpu_specifications\x18\t \x03(\x0b\x32\x43.oak9.tython.aws.ec2_instance.LaunchTemplateElasticGpuSpecification\x12}\n\x1e\x65lastic_inference_accelerators\x18\n \x03(\x0b\x32U.oak9.tython.aws.ec2_instance.LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12H\n\tplacement\x18\x0b \x01(\x0b\x32\x35.oak9.tython.aws.ec2_instance.LaunchTemplatePlacement\x12X\n\x12network_interfaces\x18\x0c \x03(\x0b\x32<.oak9.tython.aws.ec2_instance.LaunchTemplateNetworkInterface\x12\x10\n\x08image_id\x18\r \x01(\t\x12\x15\n\rinstance_type\x18\x0e \x01(\t\x12J\n\nmonitoring\x18\x0f \x01(\x0b\x32\x36.oak9.tython.aws.ec2_instance.LaunchTemplateMonitoring\x12[\n\x13hibernation_options\x18\x10 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateHibernationOptions\x12U\n\x10metadata_options\x18\x11 \x01(\x0b\x32;.oak9.tython.aws.ec2_instance.LaunchTemplateMetadataOptions\x12`\n\x16license_specifications\x18\x12 \x03(\x0b\x32@.oak9.tython.aws.ec2_instance.LaunchTemplateLicenseSpecification\x12,\n$instance_initiated_shutdown_behavior\x18\x13 \x01(\t\x12K\n\x0b\x63pu_options\x18\x14 \x01(\x0b\x32\x36.oak9.tython.aws.ec2_instance.LaunchTemplateCpuOptions\x12\x1a\n\x12security_group_ids\x18\x15 \x03(\t\x12\x10\n\x08key_name\x18\x16 \x01(\t\x12\x1f\n\x17\x64isable_api_termination\x18\x17 \x01(\x08\x12\x62\n\x17instance_market_options\x18\x18 \x01(\x0b\x32\x41.oak9.tython.aws.ec2_instance.LaunchTemplateInstanceMarketOptions\x12\x13\n\x0bram_disk_id\x18\x19 \x01(\t\x12x\n\"capacity_reservation_specification\x18\x1a \x01(\x0b\x32L.oak9.tython.aws.ec2_instance.LaunchTemplateCapacityReservationSpecification\x12]\n\x14\x63redit_specification\x18\x1b \x01(\x0b\x32?.oak9.tython.aws.ec2_instance.LaunchTemplateCreditSpecification\"&\n\tPlacement\x12\x19\n\x11\x61vailability_zone\x18\x01 \x01(\t\"\xc5\x01\n\x0eLaunchTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14launch_template_name\x18\x02 \x01(\t\x12\\\n\x14launch_template_data\x18\x03 \x01(\x0b\x32>.oak9.tython.aws.ec2_instance.LaunchTemplateLaunchTemplateDatab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_instance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INSTANCE_TAGSENTRY._options = None
  _INSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._options = None
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCEEBS._serialized_start=82
  _INSTANCEEBS._serialized_end=299
  _INSTANCENODEVICE._serialized_start=301
  _INSTANCENODEVICE._serialized_end=376
  _INSTANCEBLOCKDEVICEMAPPING._serialized_start=379
  _INSTANCEBLOCKDEVICEMAPPING._serialized_end=630
  _INSTANCECPUOPTIONS._serialized_start=632
  _INSTANCECPUOPTIONS._serialized_end=755
  _INSTANCECREDITSPECIFICATION._serialized_start=757
  _INSTANCECREDITSPECIFICATION._serialized_end=864
  _INSTANCEELASTICGPUSPECIFICATION._serialized_start=866
  _INSTANCEELASTICGPUSPECIFICATION._serialized_end=956
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_start=958
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_end=1067
  _INSTANCEHIBERNATIONOPTIONS._serialized_start=1069
  _INSTANCEHIBERNATIONOPTIONS._serialized_end=1174
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_start=1176
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_end=1284
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_start=1287
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_end=1456
  _INSTANCELICENSESPECIFICATION._serialized_start=1458
  _INSTANCELICENSESPECIFICATION._serialized_end=1580
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_start=1583
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_end=1724
  _INSTANCENETWORKINTERFACE._serialized_start=1727
  _INSTANCENETWORKINTERFACE._serialized_end=2271
  _INSTANCEASSOCIATIONPARAMETER._serialized_start=2273
  _INSTANCEASSOCIATIONPARAMETER._serialized_end=2388
  _INSTANCESSMASSOCIATION._serialized_start=2391
  _INSTANCESSMASSOCIATION._serialized_end=2587
  _INSTANCEVOLUME._serialized_start=2589
  _INSTANCEVOLUME._serialized_end=2697
  _INSTANCE._serialized_start=2700
  _INSTANCE._serialized_end=4563
  _INSTANCE_TAGSENTRY._serialized_start=4520
  _INSTANCE_TAGSENTRY._serialized_end=4563
  _EC2_INSTANCE._serialized_start=4566
  _EC2_INSTANCE._serialized_end=4709
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_start=4712
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_end=4955
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_start=4520
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_end=4563
  _LAUNCHTEMPLATEEBS._serialized_start=4958
  _LAUNCHTEMPLATEEBS._serialized_end=5181
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_start=5184
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_end=5399
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_start=5401
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_end=5519
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_start=5521
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_end=5617
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_start=5620
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_end=5749
  _LAUNCHTEMPLATEPLACEMENT._serialized_start=5752
  _LAUNCHTEMPLATEPLACEMENT._serialized_end=6015
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_start=6018
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_end=6148
  _LAUNCHTEMPLATEIPV6ADD._serialized_start=6150
  _LAUNCHTEMPLATEIPV6ADD._serialized_end=6252
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_start=6255
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_end=6809
  _LAUNCHTEMPLATEMONITORING._serialized_start=6811
  _LAUNCHTEMPLATEMONITORING._serialized_end=6911
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_start=6913
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_end=7024
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_start=7027
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_end=7196
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_start=7199
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_end=7327
  _LAUNCHTEMPLATECPUOPTIONS._serialized_start=7330
  _LAUNCHTEMPLATECPUOPTIONS._serialized_end=7459
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_start=7462
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_end=7686
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_start=7689
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_end=7883
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_start=7886
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_end=8017
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_start=8020
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_end=8274
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_start=8276
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_end=8389
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_start=8392
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_end=10179
  _PLACEMENT._serialized_start=10181
  _PLACEMENT._serialized_end=10219
  _LAUNCHTEMPLATE._serialized_start=10222
  _LAUNCHTEMPLATE._serialized_end=10419
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_codestarnotifications.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#aws/aws_codestarnotifications.proto\x12%oak9.tython.aws.codestarnotifications\x1a\x13shared/shared.proto\"~\n\x16NotificationRuleTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0btarget_type\x18\x02 \x01(\t\x12\x16\n\x0etarget_address\x18\x03 \x01(\t\"\xf6\x02\n\x10NotificationRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65vent_type_ids\x18\x02 \x03(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65tail_type\x18\x04 \x01(\t\x12\x10\n\x08resource\x18\x05 \x01(\t\x12N\n\x07targets\x18\x06 \x03(\x0b\x32=.oak9.tython.aws.codestarnotifications.NotificationRuleTarget\x12O\n\x04tags\x18\x07 \x03(\x0b\x32\x41.oak9.tython.aws.codestarnotifications.NotificationRule.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x15\x43odeStarNotifications\x12R\n\x11notification_rule\x18\x01 \x03(\x0b\x32\x37.oak9.tython.aws.codestarnotifications.NotificationRuleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_codestarnotifications_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTIFICATIONRULE_TAGSENTRY._options = None
  _NOTIFICATIONRULE_TAGSENTRY._serialized_options = b'8\001'
  _NOTIFICATIONRULETARGET._serialized_start=99
  _NOTIFICATIONRULETARGET._serialized_end=225
  _NOTIFICATIONRULE._serialized_start=228
  _NOTIFICATIONRULE._serialized_end=602
  _NOTIFICATIONRULE_TAGSENTRY._serialized_start=559
  _NOTIFICATIONRULE_TAGSENTRY._serialized_end=602
  _CODESTARNOTIFICATIONS._serialized_start=604
  _CODESTARNOTIFICATIONS._serialized_end=711
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_sql_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleSql(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SQL_DATABASE_FIELD_NUMBER: builtins.int
    SQL_DATABASE_INSTANCE_FIELD_NUMBER: builtins.int
    SQL_SOURCE_REPRESENTATION_INSTANCE_FIELD_NUMBER: builtins.int
    SQL_SSL_CERT_FIELD_NUMBER: builtins.int
    SQL_USER_FIELD_NUMBER: builtins.int
    @property
    def sql_database(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_sql_pb2.SqlDatabase]: ...
    @property
    def sql_database_instance(self) -> gcp.gcp_sql_pb2.SqlDatabaseInstance: ...
    @property
    def sql_source_representation_instance(self) -> gcp.gcp_sql_pb2.SqlSourceRepresentationInstance: ...
    @property
    def sql_ssl_cert(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_sql_pb2.SqlSslCert]: ...
    @property
    def sql_user(self) -> gcp.gcp_sql_pb2.SqlUser: ...
    def __init__(
        self,
        *,
        sql_database: collections.abc.Iterable[gcp.gcp_sql_pb2.SqlDatabase] | None = ...,
        sql_database_instance: gcp.gcp_sql_pb2.SqlDatabaseInstance | None = ...,
        sql_source_representation_instance: gcp.gcp_sql_pb2.SqlSourceRepresentationInstance | None = ...,
        sql_ssl_cert: collections.abc.Iterable[gcp.gcp_sql_pb2.SqlSslCert] | None = ...,
        sql_user: gcp.gcp_sql_pb2.SqlUser | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sql_database_instance", b"sql_database_instance", "sql_source_representation_instance", b"sql_source_representation_instance", "sql_user", b"sql_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["sql_database", b"sql_database", "sql_database_instance", b"sql_database_instance", "sql_source_representation_instance", b"sql_source_representation_instance", "sql_ssl_cert", b"sql_ssl_cert", "sql_user", b"sql_user"]) -> None: ...

global___GoogleSql = GoogleSql
